<?php
/**
 * Compact_One functions and definitions.
 *
 * @link
 *
 * @package compact_one
 */

/**
 * Load text domain.
 */
function compact_one_text_domain() {
	load_theme_textdomain( 'compact-one', get_template_directory() . '/languages' );
}
add_action( 'after_setup_theme', 'compact_one_text_domain' );

/**
 * Load core.
 */
require_once( get_template_directory() . '/core/init.php' );

/**
 * Enqueue scripts and styles
 */
function compact_one_enqueue() {
	$directory_uri  = get_template_directory_uri();

	wp_enqueue_style( 'animate-style', $directory_uri . '/inc/css/animate.css', false, '3.5.1' );

	wp_enqueue_script( 'waypoints', $directory_uri . '/js/jquery.waypoints.min.js', '', '',true );
	wp_enqueue_script( 'jquerycountup', $directory_uri . '/js/jquery.counterup.js', '', '',true );

	wp_enqueue_script( 'script-wow', get_template_directory_uri() . '/js/wow.min.js' );
	wp_enqueue_script( 'jquery-easing', $directory_uri . '/js/jquery.easing.min.js', array( 'jquery' ), '' );
	wp_enqueue_script( 'jquery-scrolling-nav', $directory_uri . '/js/scrolling-nav.js', array( 'jquery' ), '' );
	wp_enqueue_script( 'isotope-main', $directory_uri . '/js/isotope.pkgd.min.js', array( 'jquery' ), '', true );
	wp_enqueue_script( 'compact_one_custom_js',get_template_directory_uri() . '/js/custom.js',array( 'jquery' ),'', true );

	wp_enqueue_style( 'roboto-font', '//fonts.googleapis.com/css?family=Roboto:400,400i,500,700', false );
	wp_enqueue_style( 'lato-font', '//fonts.googleapis.com/css?family=Lato:400,700', false );
	wp_enqueue_style( 'fontawesome-style', $directory_uri . '/inc/css/font-awesome.min.css', false, '4.7.0' );

}
add_action( 'wp_enqueue_scripts', 'compact_one_enqueue' );

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640;
}

/**
 * Title tag support.
 */
function compact_one_theme_setup() {
	add_theme_support( 'title-tag' );
}
add_action( 'after_setup_theme', 'compact_one_theme_setup' );

/**
 * Require the section and customizer files.
 */
require_once( get_template_directory() . '/inc/customizer.php' );
require_once( get_template_directory() . '/inc/slider-section.php' );
require_once( get_template_directory() . '/inc/about-us-section.php' );
require_once( get_template_directory() . '/inc/features-section.php' );
require_once( get_template_directory() . '/inc/work-section.php' );
require_once( get_template_directory() . '/inc/team-section.php' );
require_once( get_template_directory() . '/inc/testimonial-section.php' );
require_once( get_template_directory() . '/inc/contact-section.php' );
require_once( get_template_directory() . '/inc/custom-functions.php' );

/**
 * Modify wpkses allowed html .
 */
function compact_one_wpkses_post_tags() {
		$tags['iframe'] = array(
			'src'             => true,
			'height'          => true,
			'width'           => true,
			'frameborder'     => true,
			'allowfullscreen' => true,
		);

	return $tags;
}
add_filter( 'wp_kses_allowed_html', 'compact_one_wpkses_post_tags', 10, 2 );

/*===================== metaboxes for team and testimonial sections =================================================*/
add_action( 'add_meta_boxes', 'compact_one_team_add_meta_box' );

/**
 * Team - meta box.
 */
function compact_one_team_add_meta_box() {
	global $post;

		add_meta_box( 'compact_one_team_meta_box', 'Team Section Options', 'compact_one_team_meta_box_cb', 'post', 'normal', 'high' );
}

/**
 * Team - meta box- details.
 */
function compact_one_team_meta_box_cb() {
	global $post;
	$values = get_post_custom( $post->ID );
	$compact_one_meta_box_text_designation = isset( $values['compact_one_meta_box_text_designation'] ) ? $values['compact_one_meta_box_text_designation'][0] : '';
	$compact_one_meta_box_text_facebook = isset( $values['compact_one_meta_box_text_facebook'] ) ? $values['compact_one_meta_box_text_facebook'][0] : '';
	$compact_one_meta_box_text_twitter = isset( $values['compact_one_meta_box_text_twitter'] ) ? $values['compact_one_meta_box_text_twitter'][0] : '';
	$compact_one_meta_box_text_googleplus = isset( $values['compact_one_meta_box_text_googleplus'] ) ? $values['compact_one_meta_box_text_googleplus'][0] : '';
	$compact_one_meta_box_text_linkedin = isset( $values['compact_one_meta_box_text_linkedin'] ) ? $values['compact_one_meta_box_text_linkedin'][0] : '';
	$compact_one_meta_box_text_pinterest = isset( $values['compact_one_meta_box_text_pinterest'] ) ? $values['compact_one_meta_box_text_pinterest'][0] : '';

	wp_nonce_field( 'compact_one_meta_box_nonce', 'meta_box_nonce' );
?>
	<p><?php echo esc_html( __( "To use this post for front page's team section, please enter below details:",'compact-one' ) ); ?>
	</p>
	<p>
		<label for="compact_one_meta_box_text_designation"><?php echo esc_html( __( 'Member designation','compact-one' ) ); ?></label>
		<input type="text" name="compact_one_meta_box_text_designation" id="compact_one_meta_box_text_designation" value="<?php echo esc_attr( $compact_one_meta_box_text_designation ); ?>" />
	</p> 
	<p>
		<label for="compact_one_meta_box_text_facebook"><?php echo esc_html( __( 'Facebook Link','compact-one' ) ); ?></label>
		<input type="text" name="compact_one_meta_box_text_facebook" id="compact_one_meta_box_text_facebook" value="<?php echo esc_attr( $compact_one_meta_box_text_facebook ); ?>" />
	</p> 
	<p>
		<label for="compact_one_meta_box_text_twitter"><?php echo esc_html( __( 'Twitter Link','compact-one' ) ); ?></label>
		<input type="text" name="compact_one_meta_box_text_twitter" id="compact_one_meta_box_text_twitter" value="<?php echo esc_attr( $compact_one_meta_box_text_twitter ); ?>" />
	</p> 
	<p>
		<label for="compact_one_meta_box_text_googleplus"><?php echo esc_html( __( 'GooglePlus Link','compact-one' ) ); ?></label>
		<input type="text" name="compact_one_meta_box_text_googleplus" id="compact_one_meta_box_text_googleplus" value="<?php echo esc_attr( $compact_one_meta_box_text_googleplus ); ?>" />
	</p> 
	<p>
		<label for="compact_one_meta_box_text_linkedin"><?php echo esc_html( __( 'LinkedIn Link','compact-one' ) ); ?></label>
		<input type="text" name="compact_one_meta_box_text_linkedin" id="compact_one_meta_box_text_linkedin" value="<?php echo esc_attr( $compact_one_meta_box_text_linkedin ); ?>" />
	</p> 
	<p>
		<label for="compact_one_meta_box_text_pinterest"><?php echo esc_html( __( 'Pinterest Link','compact-one' ) ); ?></label>
		<input type="text" name="compact_one_meta_box_text_pinterest" id="compact_one_meta_box_text_pinterest" value="<?php echo esc_attr( $compact_one_meta_box_text_pinterest ); ?>" />
	</p>  
<?php
}

/**
 * Team-meta box save.
 *
 * @param array $post_id Metabox entry data.
 */
function compact_one_team_meta_box_save( $post_id ) {
	$allowed = array(
		'a' => array( // on allow a tags.
			'href' => array(), // and those anchors can only have href attribute.
		),
	);

	if ( isset( $_POST['compact_one_meta_box_text_designation'] ) ) {
		update_post_meta( $post_id, 'compact_one_meta_box_text_designation', wp_kses( $_POST['compact_one_meta_box_text_designation'], $allowed ) );
	}
	if ( isset( $_POST['compact_one_meta_box_text_facebook'] ) ) {
		update_post_meta( $post_id, 'compact_one_meta_box_text_facebook', wp_kses( $_POST['compact_one_meta_box_text_facebook'], $allowed ) );
	}
	if ( isset( $_POST['compact_one_meta_box_text_twitter'] ) ) {
		update_post_meta( $post_id, 'compact_one_meta_box_text_twitter', wp_kses( $_POST['compact_one_meta_box_text_twitter'], $allowed ) );
	}
	if ( isset( $_POST['compact_one_meta_box_text_googleplus'] ) ) {
		update_post_meta( $post_id, 'compact_one_meta_box_text_googleplus', wp_kses( $_POST['compact_one_meta_box_text_googleplus'], $allowed ) );
	}
	if ( isset( $_POST['compact_one_meta_box_text_linkedin'] ) ) {
		update_post_meta( $post_id, 'compact_one_meta_box_text_linkedin', wp_kses( $_POST['compact_one_meta_box_text_linkedin'], $allowed ) );
	}
	if ( isset( $_POST['compact_one_meta_box_text_pinterest'] ) ) {
		update_post_meta( $post_id, 'compact_one_meta_box_text_pinterest', wp_kses( $_POST['compact_one_meta_box_text_pinterest'], $allowed ) );
	}
}
add_action( 'save_post', 'compact_one_team_meta_box_save' );

// metabox for testimonial section
add_action( 'add_meta_boxes', 'compact_one_testimonial_add_meta_box' );

function compact_one_testimonial_add_meta_box() {
	global $post;

		add_meta_box( 'compact_one_testmonial_meta_box', 'Testimonial Section Options', 'compact_one_testimonial_meta_box_cb', 'post', 'normal', 'high' );
}
function compact_one_testimonial_meta_box_cb() {
	global $post;
	$values = get_post_custom( $post->ID );
	$compact_one_meta_box_abt_client = isset( $values['compact_one_meta_box_abt_client'] ) ? $values['compact_one_meta_box_abt_client'][0] : '';

	wp_nonce_field( 'compact_one_testimonial_meta_box_nonce', 'meta_box_nonce_testimonial' );
?>
	<p><?php echo esc_html( __( "To use this post for front page's testimonial section, please enter below details:",'compact-one' ) ); ?>
	</p>
	<p>
		<label for="compact_one_meta_box_abt_client"><?php echo esc_html( __( 'About the client','compact-one' ) ); ?></label>
		<input type="text" name="compact_one_meta_box_abt_client" id="compact_one_meta_box_abt_client" value="<?php echo $compact_one_meta_box_abt_client; ?>" />
	</p> 
<?php
}
add_action( 'save_post', 'compact_one_testimonial_meta_box_save' );
function compact_one_testimonial_meta_box_save( $post_id ) {
	$allowed = array(
		'a' => array( // on allow a tags
			'href' => array(), // and those anchors can only have href attribute
		),
	);

	if ( isset( $_POST['compact_one_meta_box_abt_client'] ) ) {
		update_post_meta( $post_id, 'compact_one_meta_box_abt_client', wp_kses( $_POST['compact_one_meta_box_abt_client'], $allowed ) );
	}
}
/*=============================== end of meta box code ========================================*/

/** 
 * Styles for header
 */
function compact_one_custom_styles() {
	// check if slider is enabled else modify menu.
	$compact_one_enable_slider_section = get_theme_mod( 'compact_one_enable_slider_section', 1 );
	if ( empty( $compact_one_enable_slider_section ) ) {
	?>
		<style>
			.page-template-template-home .navbar-default
			{
					background: rgba(58, 101, 145, 0.9);
					position: relative;
					margin-top: 0;
			}
			.page-template-template-home .sticky-header2 .navbar-default
			{
				position:fixed;
			}
		</style>
<?php
	}
}
add_action( 'wp_head', 'compact_one_custom_styles', 100 );

/**
 * Add theme specific social option design
 *
 * @param array $orig social icon list.
 */
function compact_one_social_icon_options( $orig ) {
	$new = array(
		'theme-specific' => get_template_directory_uri() . '/inc/images/icons-theme.png',
	);
	$new = array_merge( $new, $orig );
	return $new;
}
add_filter( 'cyberchimps_social_icon_options','compact_one_social_icon_options' );

if ( ! function_exists( 'compact_one_post_nav' ) ) :
	/**
	 * Display navigation to next/previous post when applicable.
	 */
	function compact_one_post_nav() {
		// Don't print empty markup if there's nowhere to navigate.
		$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
		$next     = get_adjacent_post( false, '', false );

		if ( ! $next && ! $previous ) {
			return;
		}
		?>
		<nav class="navigation post-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Post navigation', 'compact-one' ); ?></h1>
		<div class="nav-links">
			<?php
				previous_post_link( '<div class="nav-previous">%link</div>', _x( '<span class="meta-nav">&larr;</span>&nbsp;%title', 'Previous post link', 'compact-one' ) );
				next_post_link( '<div class="nav-next">%link</div>',     _x( '%title&nbsp;<span class="meta-nav">&rarr;</span>', 'Next post link',     'compact-one' ) );
			?>
			</div><!-- .nav-links -->
			</nav><!-- .navigation -->
			<?php
	}
endif;

/**
 * Customizer partial refresh
 */
function compact_one_customize_edit_links( $wp_customize ) {

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	$wp_customize->selective_refresh->add_partial(
		'blogname', array(
			'selector' => '.site-title a',
			'render_callback' => 'compact_one_customize_partial_blogname',
		)
	);

	$wp_customize->selective_refresh->add_partial(
		'blogdescription', array(
			'selector' => '.blog-description p',
			'render_callback' => 'compact_one_customize_partial_blogdescription',
		)
	);

	$wp_customize->selective_refresh->add_partial(
		'theme_backgrounds', array(
			'selector' => '#social',
		)
	);

	$wp_customize->selective_refresh->add_partial(
		'footer_copyright_text', array(
			'selector' => '#copyright',
		)
	);

	$wp_customize->selective_refresh->add_partial(
		'nav_menu_locations[primary]', array(
			'selector' => '#navigation',
		)
	);
	// home page sections.
	$wp_customize->selective_refresh->add_partial(
		'compact_one_about_title', array(
			'selector' => '#compact_one_about_section .section_title_span',
		)
	);
	$wp_customize->selective_refresh->add_partial(
		'compact_one_features_title', array(
			'selector' => '#compact_one_features_section .section_title_span',
		)
	);
	$wp_customize->selective_refresh->add_partial(
		'compact_one_work_title', array(
			'selector' => '#compact_one_work_section .section_title_span',
		)
	);
	$wp_customize->selective_refresh->add_partial(
		'compact_one_team_title', array(
			'selector' => '#compact_one_team_section .section_title_span',
		)
	);
	$wp_customize->selective_refresh->add_partial(
		'compact_one_testimonial_title', array(
			'selector' => '#compact_one_testimonial_section .section_title_span',
		)
	);
	$wp_customize->selective_refresh->add_partial(
		'compact_one_contact_title', array(
			'selector' => '#compact_one_contact_section .section_title_span',
		)
	);

}
/**
 * Customizer partial refresh - blogname
 */
function compact_one_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Customizer partial refresh - blog-description
 */
function compact_one_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

add_action( 'customize_register', 'compact_one_customize_edit_links' );
