<?php
/**
 * Custom functions template
 *
 * @package compact-one
 */

/**
 * Modify footer
 */
function compact_one_custom_functions() {
	remove_action( 'cyberchimps_footer', 'cyberchimps_footer_credit' );
	add_action( 'cyberchimps_footer', 'compact_one_footer_credit' );
}
add_action( 'init', 'compact_one_custom_functions' );

/*================= Fonts =====================*/

/**
 * List for sizes
 *
 * @param array $sizes Typography sizes.
 */
function compact_one_typography_sizes( $sizes ) {
	$sizes = array( '8', '9', '10', '12', '14', '15', '16', '18', '20' );
	return $sizes;
}
add_filter( 'cyberchimps_typography_sizes', 'compact_one_typography_sizes' );

/**
 * List for styles
 *
 * @param array $styles Typography styles.
 */
function compact_one_typography_styles( $styles ) {
	$styles = array(
		'normal' => 'Normal',
		'bold' => 'Bold',
	);
	return $styles;
}
add_filter( 'cyberchimps_typography_styles', 'compact_one_typography_styles' );

/**
 * Adding raleway font to main list
 *
 * @param array $orig Typography faces.
 */
function compact_one_typography_faces( $orig ) {

	$new = array(
		'"Roboto", sans-serif' => 'Roboto',
	);

	$new = array_merge( $new, $orig );

	return $new;
}
add_filter( 'cyberchimps_typography_faces', 'compact_one_typography_faces' );

/**
 * Setting defaults - body
 */
function compact_one_typography_defaults() {
	$default = array(
		'size' => '16px',
		'face' => '"Roboto", sans-serif',
		'style' => 'normal',
		'color' => '',
	);

	return $default;
}
add_filter( 'cyberchimps_typography_defaults', 'compact_one_typography_defaults' );

/**
 * Setting defaults - menu
 */
function compact_one_menu_typography_style() {
	$default = array(
		'face' => '"Roboto", sans-serif',
	);
	return $default;
}
add_filter( 'cyberchimps_typography_menu_defaults', 'compact_one_menu_typography_style' );

/**
 * Footer area modified
 */
function compact_one_footer_credit() {
?>
	<footer class="container-full-width" id="after_footer">
		<div class="compact_one_footer_icons">
			<?php cyberchimps_header_social_icons(); ?>
		</div><!-- end of .compact_one_footer_icons -->

		<div class="compact_one_footer_copyright">
			<div class="container">
				<!-- logo -->
				<?php $compact_one_footer_image = get_theme_mod( 'compact_one_footer_image' ); ?>
				<?php if ( ! empty( $compact_one_footer_image ) ) { ?>
					<img class="compact_one_footer_image" src="<?php echo esc_attr( $compact_one_footer_image ); ?>" alt="<?php esc_attr_e( 'footer image','compact-one' ); ?>" />
				<?php } ?>
				<!--cyberchimps link -->
				<div id="credit">					
					<a href="<?php echo esc_url( __( 'http://cyberchimps.com/','cyberchimps_core' ) ); ?>" target="_blank" title="<?php echo esc_attr_e( 'CyberChimps Themes','compact-one' ); ?>" rel="noindex, nofollow">									
						<h4 class="cc-credit-text"><?php esc_html_e( 'CyberChimps WordPress Themes', 'cyberchimps_core' ); ?></h4>
						<span class="screen-reader-text"><?php esc_html_e( 'Theme home page (will open in a new window)', 'cyberchimps_core' ); ?></span>
					</a>								
				</div><!-- end of .credit -->
				
				<!-- copyright text -->
				<?php $copyright = ( get_theme_mod( 'footer_copyright_text' ) ) ? get_theme_mod( 'footer_copyright_text' ) : '&copy; ' . date( 'Y' ) . ' <a href="' . esc_url( home_url( '/' ) ) . '" title="' . esc_attr( get_bloginfo( 'name', 'display' ) ) . '">' . esc_attr( get_bloginfo( 'name' ) ) . '</a>'; ?>
				<div id="copyright">
					<?php echo wp_kses_post( $copyright ); ?>
				</div>
			</div><!-- end of .container -->
		</div><!-- end of .compact_one_footer_copyright -->

	</footer><!-- end of #after_footer -->
		
	<div id="scroll-to-top"><span class="glyphicon glyphicon-chevron-up"></span></div>	
<?php
}

/**
 * Theme options compatibility
 */
function compact_one_theme_options_compatibility() {
	// link, text, heading colors.
	$text_colorpicker = get_theme_mod( 'text_colorpicker' );
	$link_colorpicker = get_theme_mod( 'link_colorpicker' );
	$link_hover_colorpicker = get_theme_mod( 'link_hover_colorpicker' );

?>
	<style type="text/css">
		
		/* text color */
		body, #compact_one_slider .caption, #compact_one_about_section .progress-title, #compact_one_about_section .progress-bar, #compact_one_features_section .feature_each_desc, #compact_one_work_section .company_profile_section .ht_pt_count, #compact_one_work_section .company_profile_section .ht_pt_heading, #compact_one_testimonial_section .testimonial_abt, #compact_one_testimonial_section .testimonial_text, #after_footer .compact_one_footer_copyright #copyright, .text-muted
		{
			color:<?php echo esc_attr( $text_colorpicker ); ?>;
		}		
		/* link color */
		a, #compact_one_work_section .tw_portfolio_hover_layer a, #compact_one_team_section .team_member_details .tw_showcase_designation, #compact_one_team_section .team_member_details .tw_showcase_desc
		{
			color:<?php echo esc_attr( $link_colorpicker ); ?>;
		}
		/* link hover color */
		a:hover, #compact_one_work_section .tw_portfolio_hover_layer a:hover, #compact_one_team_section .team_member_details .tw_showcase_designation:hover, #compact_one_team_section .team_member_details .tw_showcase_desc:hover
		{
			color:<?php echo esc_attr( $link_hover_colorpicker ); ?>;
		} 
	</style>
<?php
}
add_action( 'wp_head', 'compact_one_theme_options_compatibility' );
