<?php
/**
 * Theme options in customizer
 *
 * @package compact-one
 */

/**
 * Customizer options
 *
 * @param array $wp_customize Customizer options.
 */
function compact_one_free_customizer_register( $wp_customize ) {

	/**
	 * Class CyberChimps_Customize_Heading
	 *
	 * Creates a form heading to show headings for sub-sections
	 */
	class CyberChimps_Customize_Heading extends WP_Customize_Control {
		/**
		 * Heading for customizer options
		 *
		 * @var type.
		 */
		public $type = 'heading';

		/**
		 * Display content.
		 */
		public function render_content() {
			if ( ! empty( $this->label ) ) : ?>
				<h3 class="total-accordion-section-title"><?php echo esc_html( $this->label ); ?></h3>
			<?php
			endif;

			if ( $this->description ) {
			?>
				<span class="description customize-control-description">
				<?php echo wp_kses_post( $this->description ); ?>
				</span>
			<?php
			}
		}
	}

	/* Option list of all post */
	$options_posts = array();
	$options_posts_obj = new WP_Query(
		array(
			'posts_per_page' => 100,
		)
	);
	$options_posts[''] = esc_html( __( 'Choose Post', 'compact-one' ) );
	if ( $options_posts_obj->have_posts() ) {
		while ( $options_posts_obj->have_posts() ) :
			$options_posts_obj->the_post();
			$post_id = get_the_ID();
			$options_posts[ $post_id ] = get_the_title();
		endwhile;
		wp_reset_postdata();
	}

	/* Option list of all categories */
	$args = array(
		'type'         => 'post',
		'orderby'      => 'name',
		'order'        => 'ASC',
		'hide_empty'   => 1,
		'hierarchical' => 1,
		'taxonomy'     => 'category',
	);
	$option_categories = array();
	$category_lists = get_categories( $args );
	$option_categories[''] = esc_html( __( 'Choose Category', 'compact-one' ) );
	foreach ( $category_lists as $category ) {
		$option_categories[ $category->term_id ] = $category->name;
	}
	 /* Option list of all pages */
	$options_pages = array();
	$options_pages_obj = new WP_Query(
		array(
			'posts_per_page' => 100,
			'post_type' => 'page',
		)
	);
	$options_pages[''] = esc_html( __( 'Choose Page', 'compact-one' ) );
	if ( $options_pages_obj->have_posts() ) {
		while ( $options_pages_obj->have_posts() ) :
			$options_pages_obj->the_post();
			$post_id = get_the_ID();
			$options_pages[ $post_id ] = get_the_title();
		endwhile;
		wp_reset_postdata();
	}

	 $wp_customize->add_panel(
		 'home_page_settings', array(
			 'priority' => 46,
			 'capability' => 'edit_theme_options',
			 'theme_supports' => '',
			 'title' => esc_html( __( 'Home Page Settings', 'compact-one' ) ),
			 'description' => esc_html( __( 'Please create a page and choose the "Home Template" from the right side. These home page settings will apply to this page. To view this page as the front page, please choose this page for the setting "A static page" under the "Static Front Page" option.', 'compact-one' ) ),
		 )
	 );

	/*============== slider =====================*/
	 $wp_customize->add_section(
		 'compact_one_slider_section', array(
			 'priority' => 10,
			 'capability' => 'edit_theme_options',
			 'theme_supports' => '',
			 'title' => esc_html( __( 'Slider Section', 'compact-one' ) ),
			 'panel' => 'home_page_settings',
		 )
	 );
	// enable section.
	$wp_customize->add_setting(
		'compact_one_enable_slider_section', array(
			'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
			'default' => 1,
		)
	);

	$wp_customize->add_control(
		'compact_one_enable_slider_section', array(
			'label' => esc_html( __( 'Enable Section', 'compact-one' ) ),
			'section' => 'compact_one_slider_section',
			'settings' => 'compact_one_enable_slider_section',
			'type' => 'checkbox',
		)
	);
	// menu name.
	$wp_customize->add_setting(
		'compact_one_slider_menu_title', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'Home','compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_slider_menu_title', array(
			'label' => esc_html( __( 'Menu Name', 'compact-one' ) ),
			'section' => 'compact_one_slider_section',
			'settings' => 'compact_one_slider_menu_title',
			'type' => 'text',
		)
	);
	// choose post.
	$wp_customize->add_setting(
		'compact_one_slider_category',
		array(
			'default' => '',
			'sanitize_callback' => 'cyberchimps_sanitize_select_post',
		)
	);
	$wp_customize->add_control(
		'compact_one_slider_category',
		array(
			'label' => esc_html( __( 'Select Category', 'compact-one' ) ),
			'section' => 'compact_one_slider_section',
			'type' => 'select',
			'choices' => $option_categories,
			'description' => esc_html( __( 'The featured image from the posts will be displayed for the slider. Recommended image size for the featured images: 1920 x 606px', 'compact-one' ) ),
		)
	);

	/*============== About =====================*/
	$wp_customize->add_section(
		'compact_one_about_section', array(
			'priority' => 10,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => esc_html( __( 'About Section', 'compact-one' ) ),
			'panel' => 'home_page_settings',
		)
	);
	// enable section.
	$wp_customize->add_setting(
		'compact_one_enable_about_section', array(
			'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
			'default' => 1,
		)
	);

	$wp_customize->add_control(
		'compact_one_enable_about_section', array(
			'label' => esc_html( __( 'Enable Section', 'compact-one' ) ),
			'section' => 'compact_one_about_section',
			'settings' => 'compact_one_enable_about_section',
			'type' => 'checkbox',
		)
	);
	// menu name.
	$wp_customize->add_setting(
		'compact_one_about_menu_title', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'About Us', 'compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_about_menu_title', array(
			'label' => esc_html( __( 'Menu Name', 'compact-one' ) ),
			'section' => 'compact_one_about_section',
			'settings' => 'compact_one_about_menu_title',
			'type' => 'text',
		)
	);
	// section title.
	$wp_customize->add_setting(
		'compact_one_about_title', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'About Us', 'compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_about_title', array(
			'label' => esc_html( __( 'Section Title', 'compact-one' ) ),
			'section' => 'compact_one_about_section',
			'settings' => 'compact_one_about_title',
			'type' => 'text',
		)
	);
	// choose page -for description.
	$wp_customize->add_setting(
		'compact_one_about_desc',
		array(
			'default' => '',
			'sanitize_callback' => 'cyberchimps_sanitize_select_post',
		)
	);
	$wp_customize->add_control(
		'compact_one_about_desc',
		array(
			'label' => esc_html( __( 'Select Page ( for description )', 'compact-one' ) ),
			'section' => 'compact_one_about_section',
			'type' => 'select',
			'choices' => $options_pages,
			'description' => esc_html( __( 'The page content will be displayed as the description for this section', 'compact-one' ) ),
		)
	);
	// subsection-skills.
	// main title.
	$wp_customize->add_setting(
		'compact_one_skills_title', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'Our Skills', 'compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_skills_title', array(
			'label' => esc_html( __( 'Skills sub-section title', 'compact-one' ) ),
			'section' => 'compact_one_about_section',
			'settings' => 'compact_one_skills_title',
			'type' => 'text',
		)
	);

	// other data - skills.
	for ( $i = 1; $i < 5; $i++ ) {
		$wp_customize->add_setting(
			'compact_one_each_skill_title_' . $i,
			array(
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			new CyberChimps_Customize_Heading(
				$wp_customize,
				'compact_one_each_skill_title_' . $i,
				array(
					'settings'      => 'compact_one_each_skill_title_' . $i,
					'section'       => 'compact_one_about_section',
					'label'         => esc_html( __( 'Skill ', 'compact-one' ) ) . $i,
				)
			)
		);

		// skills heading.
		$wp_customize->add_setting(
			'compact_one_skill_heading_' . $i,
			array(
				'sanitize_callback' => 'sanitize_text_field',
				'default'           => esc_html( __( 'Skill Heading ','compact-one' ) ) . $i,
			)
		);
		$wp_customize->add_control(
			'compact_one_skill_heading_' . $i,
			array(
				'settings'      => 'compact_one_skill_heading_' . $i,
				'section'       => 'compact_one_about_section',
				'type'          => 'text',
				'label'         => esc_html( __( 'Heading', 'compact-one' ) ),
			)
		);
		// skill percentage.
		$wp_customize->add_setting(
			'compact_one_skill_percentage_' . $i,
			array(
				'sanitize_callback' => 'sanitize_text_field',
				'default'           => '90',
			)
		);
		$wp_customize->add_control(
			'compact_one_skill_percentage_' . $i,
			array(
				'settings'      => 'compact_one_skill_percentage_' . $i,
				'section'       => 'compact_one_about_section',
				'type'          => 'text',
				'label'         => esc_html( __( 'Percentage', 'compact-one' ) ),
			)
		);
	}

	// sub section -company values.
	// main title.
	$wp_customize->add_setting(
		'compact_one_co_values_title', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'Why Choose Us', 'compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_co_values_title', array(
			'label' => esc_html( __( 'Company Values subsection title', 'compact-one' ) ),
			'section' => 'compact_one_about_section',
			'settings' => 'compact_one_co_values_title',
			'type' => 'text',
		)
	);
	// other data - company values.
	for ( $i = 1; $i < 4; $i++ ) {
		$wp_customize->add_setting(
			'compact_one_each_value_title_' . $i,
			array(
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			new CyberChimps_Customize_Heading(
				$wp_customize,
				'compact_one_each_value_title_' . $i,
				array(
					'settings'      => 'compact_one_each_value_title_' . $i,
					'section'       => 'compact_one_about_section',
					'label'         => esc_html( __( 'Company Value ', 'compact-one' ) ) . $i,
				)
			)
		);

		// company values heading.
		$wp_customize->add_setting(
			'compact_one_value_heading_' . $i,
			array(
				'sanitize_callback' => 'sanitize_text_field',
				'default' => esc_html( __( 'Our Achievements','compact-one' ) ),
			)
		);
		$wp_customize->add_control(
			'compact_one_value_heading_' . $i,
			array(
				'settings'      => 'compact_one_value_heading_' . $i,
				'section'       => 'compact_one_about_section',
				'type'          => 'text',
				'label'         => esc_html( __( 'Heading', 'compact-one' ) ),
			)
		);
		// value description.
		$wp_customize->add_setting(
			'compact_one_value_desc_' . $i,
			array(
				'default' => '',
				'sanitize_callback' => 'cyberchimps_sanitize_select_post',
			)
		);
		$wp_customize->add_control(
			'compact_one_value_desc_' . $i,
			array(
				'label' => esc_html( __( 'Select Post ( for the description )', 'compact-one' ) ),
				'section' => 'compact_one_about_section',
				'type' => 'select',
				'settings'      => 'compact_one_value_desc_' . $i,
				'choices' => $options_posts,
				'description' => esc_html( __( 'The post content will be the description of the value', 'compact-one' ) ),
			)
		);
	}

	/*============== Features =====================*/
	$wp_customize->add_section(
		'compact_one_features_section', array(
			'priority' => 10,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => esc_html( __( 'Features Section', 'compact-one' ) ),
			'panel' => 'home_page_settings',
		)
	);
	// enable section.
	$wp_customize->add_setting(
		'compact_one_enable_features_section', array(
			'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
			'default' => 1,
		)
	);

	$wp_customize->add_control(
		'compact_one_enable_features_section', array(
			'label' => esc_html( __( 'Enable Section', 'compact-one' ) ),
			'section' => 'compact_one_features_section',
			'settings' => 'compact_one_enable_features_section',
			'type' => 'checkbox',
		)
	);
	// menu name.
	$wp_customize->add_setting(
		'compact_one_features_menu_title', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'Features','compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_features_menu_title', array(
			'label' => esc_html( __( 'Menu Name', 'compact-one' ) ),
			'section' => 'compact_one_features_section',
			'settings' => 'compact_one_features_menu_title',
			'type' => 'text',
		)
	);
	// section title.
	$wp_customize->add_setting(
		'compact_one_features_title', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'Features','compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_features_title', array(
			'label' => esc_html( __( 'Section Title', 'compact-one' ) ),
			'section' => 'compact_one_features_section',
			'settings' => 'compact_one_features_title',
			'type' => 'text',
		)
	);
	// image.
	$wp_customize->add_setting(
		'compact_one_features_image', array(
			'sanitize_callback' => 'cyberchimps_sanitize_upload',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize, 'compact_one_features_image', array(
				'label' => esc_html( __( 'Image ( will be displayed on the right )', 'compact-one' ) ),
				'section' => 'compact_one_features_section',
				'settings' => 'compact_one_features_image',
				'type' => 'image',
				'description' => esc_html( __( 'Recommended image size: 395 x 539px','compact-one' ) ),
			)
		)
	);
	// choose post category.
	$wp_customize->add_setting(
		'compact_one_features_category',
		array(
			'default' => '',
			'sanitize_callback' => 'cyberchimps_sanitize_select_post',
		)
	);
	$wp_customize->add_control(
		'compact_one_features_category',
		array(
			'label' => esc_html( __( 'Select Category', 'compact-one' ) ),
			'section' => 'compact_one_features_section',
			'type' => 'select',
			'choices' => $option_categories,
			'description' => esc_html( __( 'The featured image, title and content from the posts will be displayed for the features section. Recommended image size for the featured images: 32 x 32px', 'compact-one' ) ),
		)
	);

	/*============== Work =====================*/
	$wp_customize->add_section(
		'compact_one_work_section', array(
			'priority' => 10,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => esc_html( __( 'Work Section', 'compact-one' ) ),
			'panel' => 'home_page_settings',
		)
	);
	// enable section.
	$wp_customize->add_setting(
		'compact_one_enable_work_section', array(
			'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
			'default' => 1,
		)
	);

	$wp_customize->add_control(
		'compact_one_enable_work_section', array(
			'label' => esc_html( __( 'Enable Section', 'compact-one' ) ),
			'section' => 'compact_one_work_section',
			'settings' => 'compact_one_enable_work_section',
			'type' => 'checkbox',
		)
	);
	// menu name.
	$wp_customize->add_setting(
		'compact_one_work_menu_title', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'Our Work','compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_work_menu_title', array(
			'label' => esc_html( __( 'Menu Name', 'compact-one' ) ),
			'section' => 'compact_one_work_section',
			'settings' => 'compact_one_work_menu_title',
			'type' => 'text',
		)
	);
	// section title.
	$wp_customize->add_setting(
		'compact_one_work_title', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'Our Work','compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_work_title', array(
			'label' => esc_html( __( 'Section Title', 'compact-one' ) ),
			'section' => 'compact_one_work_section',
			'settings' => 'compact_one_work_title',
			'type' => 'text',
		)
	);
	// choose 3 post categories to display the portfolio.
	for ( $i = 1; $i < 4; $i++ ) {
		$wp_customize->add_setting(
			'compact_one_each_work_category_title_' . $i,
			array(
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			new CyberChimps_Customize_Heading(
				$wp_customize,
				'compact_one_each_work_category_title_' . $i,
				array(
					'settings'      => 'compact_one_each_work_category_title_' . $i,
					'section'       => 'compact_one_work_section',
					'label'         => esc_html( __( 'Portfolio ', 'compact-one' ) ) . $i,
				)
			)
		);

		// value description.
		$wp_customize->add_setting(
			'compact_one_work_category_' . $i,
			array(
				'default' => '',
				'sanitize_callback' => 'cyberchimps_sanitize_select_post',
			)
		);
		$wp_customize->add_control(
			'compact_one_work_category_' . $i,
			array(
				'label' => esc_html( __( 'Select Post category', 'compact-one' ) ),
				'section' => 'compact_one_work_section',
				'type' => 'select',
				'settings'      => 'compact_one_work_category_' . $i,
				'choices' => $option_categories,
				'description' => esc_html( __( 'The post title, content and featured image will be showcased as the work portfolio. Recommended image size for the featured images: 370 x 348px', 'compact-one' ) ),
			)
		);
	}

	// counter section - displaying company profile.
	// 4 inputs to show the company profile.
	for ( $i = 1; $i < 5; $i++ ) {
		$wp_customize->add_setting(
			'compact_one_each_profile_title_' . $i,
			array(
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			new CyberChimps_Customize_Heading(
				$wp_customize,
				'compact_one_each_profile_title_' . $i,
				array(
					'settings'      => 'compact_one_each_profile_title_' . $i,
					'section'       => 'compact_one_work_section',
					'label'         => esc_html( __( 'Profile ', 'compact-one' ) ) . $i,
				)
			)
		);

		// profile heading.
		$wp_customize->add_setting(
			'compact_one_profile_heading_' . $i,
			array(
				'default' => esc_html( __( 'Happy Clients','compact-one' ) ),
				'sanitize_callback' => 'sanitize_text_field',
			)
		);
		$wp_customize->add_control(
			'compact_one_profile_heading_' . $i,
			array(
				'label' => esc_html( __( 'Title', 'compact-one' ) ),
				'section' => 'compact_one_work_section',
				'type' => 'text',
				'settings'      => 'compact_one_profile_heading_' . $i,
			)
		);
		// profile value.
		$wp_customize->add_setting(
			'compact_one_profile_value_' . $i,
			array(
				'default' => '100',
				'sanitize_callback' => 'sanitize_text_field',
			)
		);
		$wp_customize->add_control(
			'compact_one_profile_value_' . $i,
			array(
				'label' => esc_html( __( 'Value', 'compact-one' ) ),
				'section' => 'compact_one_work_section',
				'type' => 'text',
				'settings'      => 'compact_one_profile_value_' . $i,
				'description' => esc_html( __( 'Please enter a numeric value', 'compact-one' ) ),
			)
		);

		// profile icon.
		$wp_customize->add_setting(
			'compact_one_profile_icon_' . $i,
			array(
				'default' => '',
				'sanitize_callback' => 'cyberchimps_sanitize_upload',
			)
		);
		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize, 'compact_one_profile_icon_' . $i,
				array(
					'label' => esc_html( __( 'Icon', 'compact-one' ) ),
					'section' => 'compact_one_work_section',
					'type' => 'image',
					'settings'      => 'compact_one_profile_icon_' . $i,
					'description' => esc_html( __( 'Recommended image size: 39 x 39px','compact-one' ) ),
				)
			)
		);
	}

	/*============== Team =====================*/
	$wp_customize->add_section(
		'compact_one_team_section', array(
			'priority' => 10,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => esc_html( __( 'Team Section', 'compact-one' ) ),
			'panel' => 'home_page_settings',
		)
	);
	// enable section.
	$wp_customize->add_setting(
		'compact_one_enable_team_section', array(
			'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
			'default' => 1,
		)
	);

	$wp_customize->add_control(
		'compact_one_enable_team_section', array(
			'label' => esc_html( __( 'Enable Section', 'compact-one' ) ),
			'section' => 'compact_one_team_section',
			'settings' => 'compact_one_enable_team_section',
			'type' => 'checkbox',
		)
	);
	// menu name.
	$wp_customize->add_setting(
		'compact_one_team_menu_title', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'Our Team','compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_team_menu_title', array(
			'label' => esc_html( __( 'Menu Name', 'compact-one' ) ),
			'section' => 'compact_one_team_section',
			'settings' => 'compact_one_team_menu_title',
			'type' => 'text',
		)
	);
	// section title.
	$wp_customize->add_setting(
		'compact_one_team_title', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'Our Team','compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_team_title', array(
			'label' => esc_html( __( 'Section Title', 'compact-one' ) ),
			'section' => 'compact_one_team_section',
			'settings' => 'compact_one_team_title',
			'type' => 'text',
		)
	);
	// choose post category.
	$wp_customize->add_setting(
		'compact_one_team_category',
		array(
			'default' => '',
			'sanitize_callback' => 'cyberchimps_sanitize_select_post',
		)
	);
	$wp_customize->add_control(
		'compact_one_team_category',
		array(
			'label' => esc_html( __( 'Select Category', 'compact-one' ) ),
			'section' => 'compact_one_team_section',
			'type' => 'select',
			'choices' => $option_categories,
			'description' => esc_html( __( 'The featured image, title and content from the posts will be used to display the team members. Recommended image size for the featured images: 300 x 443px', 'compact-one' ) ),
		)
	);

	/*============== Testimonial =====================*/
	$wp_customize->add_section(
		'compact_one_testimonial_section', array(
			'priority' => 10,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => esc_html( __( 'Testimonial Section', 'compact-one' ) ),
			'panel' => 'home_page_settings',
		)
	);
	// enable section.
	$wp_customize->add_setting(
		'compact_one_enable_testimonial_section', array(
			'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
			'default' => 1,
		)
	);

	$wp_customize->add_control(
		'compact_one_enable_testimonial_section', array(
			'label' => esc_html( __( 'Enable Section', 'compact-one' ) ),
			'section' => 'compact_one_testimonial_section',
			'settings' => 'compact_one_enable_testimonial_section',
			'type' => 'checkbox',
		)
	);
	// menu name.
	$wp_customize->add_setting(
		'compact_one_testimonial_menu_title', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'Our Clients','compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_testimonial_menu_title', array(
			'label' => esc_html( __( 'Menu Name', 'compact-one' ) ),
			'section' => 'compact_one_testimonial_section',
			'settings' => 'compact_one_testimonial_menu_title',
			'type' => 'text',
		)
	);
	// section title.
	$wp_customize->add_setting(
		'compact_one_testimonial_title', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'Our Clients','compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_testimonial_title', array(
			'label' => esc_html( __( 'Section Title', 'compact-one' ) ),
			'section' => 'compact_one_testimonial_section',
			'settings' => 'compact_one_testimonial_title',
			'type' => 'text',
		)
	);
	// image.
	$wp_customize->add_setting(
		'compact_one_testimonial_backgr_img', array(
			'sanitize_callback' => 'cyberchimps_sanitize_upload',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize, 'compact_one_testimonial_backgr_img', array(
				'label' => esc_html( __( 'Background image', 'compact-one' ) ),
				'section' => 'compact_one_testimonial_section',
				'settings' => 'compact_one_testimonial_backgr_img',
				'type' => 'image',
				'description' => esc_html( __( 'Recommended image size: 1920 x 1280px','compact-one' ) ),
			)
		)
	);
	// choose post category.
	$wp_customize->add_setting(
		'compact_one_testimonial_category',
		array(
			'default' => '',
			'sanitize_callback' => 'cyberchimps_sanitize_select_post',
		)
	);
	$wp_customize->add_control(
		'compact_one_testimonial_category',
		array(
			'label' => esc_html( __( 'Select Category', 'compact-one' ) ),
			'section' => 'compact_one_testimonial_section',
			'type' => 'select',
			'choices' => $option_categories,
			'description' => esc_html( __( 'The featured image, title and content from the posts will be used to display the client testimonials. Recommended image size for the featured images: 164 x 164px', 'compact-one' ) ),
		)
	);

	/*============== Contact =====================*/
	$wp_customize->add_section(
		'compact_one_contact_section', array(
			'priority' => 10,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => esc_html( __( 'Contact Section', 'compact-one' ) ),
			'panel' => 'home_page_settings',
		)
	);
	// enable section.
	$wp_customize->add_setting(
		'compact_one_enable_contact_section', array(
			'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
			'default' => 1,
		)
	);

	$wp_customize->add_control(
		'compact_one_enable_contact_section', array(
			'label' => esc_html( __( 'Enable Section', 'compact-one' ) ),
			'section' => 'compact_one_contact_section',
			'settings' => 'compact_one_enable_contact_section',
			'type' => 'checkbox',
		)
	);
	// menu name.
	$wp_customize->add_setting(
		'compact_one_contact_menu_title', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'Contact','compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_contact_menu_title', array(
			'label' => esc_html( __( 'Menu Name', 'compact-one' ) ),
			'section' => 'compact_one_contact_section',
			'settings' => 'compact_one_contact_menu_title',
			'type' => 'text',
		)
	);
	// section title.
	$wp_customize->add_setting(
		'compact_one_contact_title', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'Contact','compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_contact_title', array(
			'label' => esc_html( __( 'Section Title', 'compact-one' ) ),
			'section' => 'compact_one_contact_section',
			'settings' => 'compact_one_contact_title',
			'type' => 'text',
		)
	);
	// left sub section.
	$wp_customize->add_setting(
		'compact_one_contact_left_section',
		array(
			'sanitize_callback' => 'esc_url_raw',
		)
	);

		$wp_customize->add_control(
			new CyberChimps_Customize_Heading(
				$wp_customize,
				'compact_one_contact_left_section',
				array(
					'settings'      => 'compact_one_contact_left_section',
					'section'       => 'compact_one_contact_section',
					'label'         => esc_html( __( 'Left Subsection: ', 'compact-one' ) ),
				)
			)
		);
	// section title.
	$wp_customize->add_setting(
		'compact_one_contact_left_title', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'Get in touch','compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_contact_left_title', array(
			'label' => esc_html( __( 'Title', 'compact-one' ) ),
			'section' => 'compact_one_contact_section',
			'settings' => 'compact_one_contact_left_title',
			'type' => 'text',
		)
	);
	// section title.
	$wp_customize->add_setting(
		'compact_one_contact_details', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'Contact Form can be displayed here','compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_contact_details', array(
			'label' => esc_html( __( 'Contact details', 'compact-one' ) ),
			'section' => 'compact_one_contact_section',
			'settings' => 'compact_one_contact_details',
			'type' => 'text',
			'description' => esc_html( __( "Contact Form 7 plugin's shortcode can be added here",'compact-one' ) ),
		)
	);

	// right sub section.
	$wp_customize->add_setting(
		'compact_one_contact_right_section',
		array(
			'sanitize_callback' => 'esc_url_raw',
		)
	);

		$wp_customize->add_control(
			new CyberChimps_Customize_Heading(
				$wp_customize,
				'compact_one_contact_right_section',
				array(
					'settings'      => 'compact_one_contact_right_section',
					'section'       => 'compact_one_contact_section',
					'label'         => esc_html( __( 'Right Subsection: ', 'compact-one' ) ),
				)
			)
		);
	// section title.
	$wp_customize->add_setting(
		'compact_one_contact_right_title', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'Contact Info','compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_contact_right_title', array(
			'label' => esc_html( __( 'Title', 'compact-one' ) ),
			'section' => 'compact_one_contact_section',
			'settings' => 'compact_one_contact_right_title',
			'type' => 'text',
		)
	);
	// address.
	$wp_customize->add_setting(
		'compact_one_contact_right_text', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'Contact Right section text','compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_contact_right_text', array(
			'label' => esc_html( __( 'Address', 'compact-one' ) ),
			'section' => 'compact_one_contact_section',
			'settings' => 'compact_one_contact_right_text',
			'type' => 'text',
		)
	);
	// contact no.
	$wp_customize->add_setting(
		'compact_one_contact_right_no', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => '(401) 244558845',
		)
	);

	$wp_customize->add_control(
		'compact_one_contact_right_no', array(
			'label' => esc_html( __( 'Contact Number', 'compact-one' ) ),
			'section' => 'compact_one_contact_section',
			'settings' => 'compact_one_contact_right_no',
			'type' => 'text',
		)
	);
	// email id.
	$wp_customize->add_setting(
		'compact_one_contact_right_email', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html( __( 'support@compact-one.com','compact-one' ) ),
		)
	);

	$wp_customize->add_control(
		'compact_one_contact_right_email', array(
			'label' => esc_html( __( 'Email ID', 'compact-one' ) ),
			'section' => 'compact_one_contact_section',
			'settings' => 'compact_one_contact_right_email',
			'type' => 'text',
		)
	);
	// bottom sub section.
	$wp_customize->add_setting(
		'compact_one_contact_bottom_section',
		array(
			'sanitize_callback' => 'esc_url_raw',
		)
	);

		$wp_customize->add_control(
			new CyberChimps_Customize_Heading(
				$wp_customize,
				'compact_one_contact_bottom_section',
				array(
					'settings'      => 'compact_one_contact_bottom_section',
					'section'       => 'compact_one_contact_section',
					'label'         => esc_html( __( 'Bottom Subsection: ', 'compact-one' ) ),
				)
			)
		);
	// maps.
	$wp_customize->add_setting(
		'compact_one_contact_maps', array(
			'sanitize_callback' => 'wp_kses',
		)
	);

	$wp_customize->add_control(
		'compact_one_contact_maps', array(
			'label' => esc_html( __( 'Maps location', 'compact-one' ) ),
			'section' => 'compact_one_contact_section',
			'settings' => 'compact_one_contact_maps',
			'type' => 'text',
			'description' => esc_html( __( 'Go to Google maps. Steps to add: 1) Choose the location 2) Click on menu on top left corner and select "Share or embed map" 3) Select "Embed map" 4) Copy iframe code and paste here', 'compact-one' ) ),
		)
	);

	// footer image.
	$wp_customize->add_setting(
		'compact_one_footer_image', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => '',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize, 'compact_one_footer_image', array(
				'label' => esc_html( __( 'Footer image', 'compact-one' ) ),
				'section' => 'cyberchimps_footer_section',
				'settings' => 'compact_one_footer_image',
				'type' => 'image',
			)
		)
	);

}
add_action( 'customize_register', 'compact_one_free_customizer_register' );
